import { BlockObject } from "../Block";
export declare type Conflict = [string, string];
/**
 * Contains Sets of properties for any two `BlockObject`s and their associated
 * pseudo elements that are in conflict with each other.
 */
export declare class Conflicts<T> {
    conflictingProps: Set<T>;
    pseudoConflicts: Map<string, Set<T>>;
    getConflictSet(pseudo?: string): Set<T>;
}
/**
 * Given two block objects, detect all conflicting properties for itself and its
 * pseudo elements.
 * @param obj1  BlockObject one.
 * @param obj2  BlockObject two.
 * @returns The `Conflict` object that represents the full set of property conflicts.
 */
export declare function detectConflicts(obj1: BlockObject, obj2: BlockObject): Conflicts<Conflict>;
