import * as postcss from "postcss";
import * as selectorParser from "postcss-selector-parser";
export interface SourceLocation {
    filename?: string;
    line: number;
    column: number;
}
/**
 * Reduces multiple `SourceLocation` objects into a single object capturing the
 * actual location of the source code on disk.
 * @param locations  An array of SourceLoation objects.
 * @returns An object containing the line number and column number.
 */
export declare function addSourceLocations(...locations: SourceLocation[]): SourceLocation;
/**
 * Logging utility function to fetch the filename, line number and column number
 * of a given `postcss.Node`.
 * @param sourceFile  The source file name that contains this rule.
 * @param node  The PostCSS Node object in question.
 * @returns An object representing the filename, line number and column number.
 */
export declare function sourceLocation(sourceFile: string, node: postcss.Node): SourceLocation | undefined;
/**
 * Logging utility function to fetch the filename, line number and column number
 * of a given selector.
 * @param sourceFile  The source file name that contains this rule.
 * @param rule  The PostCSS Rule object containing this selector.
 * @param selector  The PostCSS selector node in question.
 * @returns An object representing the filename, line number and column number.
 */
export declare function selectorSourceLocation(sourceFile: string, rule: postcss.Rule, selector: selectorParser.Node): SourceLocation | undefined;
