import { StyleAnalysis } from "../StyleAnalysis";
import { ElementAnalysis } from "../ElementAnalysis";
import { Validator } from "./Validator";
export * from "./classPairsValidator";
export * from "./rootClassValidator";
export * from "./stateParentValidator";
export interface TemplateValidators {
    "no-root-classes": Validator;
    "no-class-pairs": Validator;
    "no-state-orphans": Validator;
    [name: string]: Validator;
}
export declare type TemplateValidatorOptions = {
    [K in keyof TemplateValidators]?: boolean | Validator;
};
/**
 * Template validator with a single method `validate` that, given a set of
 * correlations for a given element, will throw errors for invalid BlockObject
 * correlations. Validator is instantiated with tslint-style validations config.
 *
 * Validators take the form `(str: Set<BlockObject>[], err: (str: string)) => any`.
 * The first argument is the list of possible style correlations for an element.
 * The second argument is an error callback function that will throw using the
 * provided error message and include well-formatted location data.
 *
 * Current built-in validators are:
 *
 * `no-root-classes`: Prevent BlockClasses from being applied to the same element is their Root. Enabled by default.
 * `no-class-pairs`: Prevent two BlockClasses from the same Block from being applied together. Enabled by default.
 * `no-state-orphans`: Prevent a State from being applied without its parent BlockClass or Block. Enabled by default.
 *
 * @param options A hash of tslint-style template validator options.
 */
export default class TemplateValidator {
    private validators;
    private opts;
    constructor(options?: Partial<TemplateValidatorOptions>);
    /**
     * Run validation on a given set of correlations. This is called by Analyzer on
     * `endElement`.
     * @param correlations The correlations object for a given element.
     * @param locInfo Location info for the elements being validated.
     */
    validate(templateAnalysis: StyleAnalysis, element: ElementAnalysis<any, any, any>): void;
}
