export interface ErrorLocation {
    filename?: string;
    line?: number;
    column?: number;
}
/**
 * Custom CSS Blocks error base class. Will format `SourceLocation` into thrown
 * error message if provided.
 */
export declare class CssBlockError extends Error {
    static prefix: string;
    origMessage: string;
    private _location?;
    constructor(message: string, location?: ErrorLocation | void);
    private annotatedMessage();
    readonly location: ErrorLocation | void;
}
/**
 * Custom CSS Blocks error type for template analysis errors.
 */
export declare class TemplateAnalysisError extends CssBlockError {
    static prefix: string;
    constructor(message: string, location?: ErrorLocation);
}
/**
 * Custom CSS Blocks error for missing source path from PostCSS
 */
export declare class MissingSourcePath extends CssBlockError {
    static prefix: string;
    constructor();
}
/**
 * Custom CSS Blocks error for Block syntax error
 */
export declare class InvalidBlockSyntax extends CssBlockError {
    static prefix: string;
    constructor(message: string, location?: ErrorLocation);
}
