import { ObjectDictionary } from "@opticss/util";
export interface HasScopeLookup<ScopedType> {
    lookup(dotExpression: string): ScopedType | undefined;
}
export declare type Splitter = (reference: string) => [string, string] | undefined;
/**
 * Implements a lookup of a dotted reference through a hierarchy of scopes.
 * This implementation consumes up to the first dot and delegates the rest
 * to a recursive lookup -- the implementation of which needn't follow the
 * same lookup system. If no value is found before the first dot, a local
 * scope lookup is done on the entire string.
 *
 * TODO: return information about why a thing wasn't found.
 */
export declare abstract class LocalScope<ScopeContext, ScopedType> implements HasScopeLookup<ScopedType> {
    private split;
    protected _defaultContext: ScopeContext | undefined;
    private findScope;
    private finder;
    constructor(findScope: (context: ScopeContext | undefined, contextName: string) => HasScopeLookup<ScopedType> | undefined, finder: (context: ScopeContext, name: string) => ScopedType | undefined, split: (reference: string) => [string, string] | undefined, defaultContext?: ScopeContext);
    defaultContext: ScopeContext | undefined;
    /**
     * Lookup a sub-block either locally, or on a referenced foreign block.
     * @param expression A reference to a sub-block of the form `(<block-name>.)<sub-block-selector>`
     * @returns The BlockObject referenced at the supplied path.
     */
    lookup(expression: string): ScopedType | undefined;
}
export interface HasLocalScope<ScopeContext, ScopedType> {
    subScope(name: string): LocalScope<ScopeContext, ScopedType> | undefined;
    lookupLocal(name: string): ScopedType | undefined;
}
export declare class LocalScopedContext<ScopeContext extends HasLocalScope<ScopeContext, ScopedType>, ScopedType> extends LocalScope<ScopeContext, ScopedType> {
    constructor(split: Splitter, defaultContext: ScopeContext);
}
export declare class CustomLocalScope<ScopeContext extends HasScopeLookup<ScopedType> & HasLocalScope<ScopeContext, ScopedType>, ScopedType> extends LocalScope<ScopeContext, ScopedType> {
    private subScopes;
    constructor(split: Splitter, subScopes?: ObjectDictionary<ScopeContext>);
    defaultContext: ScopeContext | undefined;
    setSubScope(localName: string, context: ScopeContext): void;
}
